/************************************************************************
 This file is part of Desk-Kregator.
 Desk-Kregator is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 Desk-Kregator is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with Desk-Kregator.  If not, see <http://www.gnu.org/licenses/>.
 *************************************************************************/

String.prototype.ellipse = function(maxLength){
    if (this.length > maxLength) {
        return this.substr(0, maxLength - 3) + '...';
    }
    return this;
};

QoDesk.DeskKregator = Ext.extend(Ext.app.Module, {

    moduleType : 'internet',
    moduleId : 'DeskKregator-win',
    menuPath: 'StartMenu/Internet',

    // Conf var
    ConfExpandCollapse : false,
    ConfGoRefresh: true,
    ConfShowSummary: true,
    ConfTreePanelWidth:'254',
    ConfGridPanelHeight:'150',
    ConfPreviewPanelSouthHeight:'300',
    ConfPreviewPanelEastWidth:'400',
    ConfPreviewPane:'bottom',
    ConfRefreshFeed:'10',
    ConfOldItems:false,
    ConfOldItemsDay:'30',

    // Panel
    PanelFeedTree:'',
    PanelFeedTreeEditor:'',
    PanelGridItem:'',
    PanelPreview:'',
    PanelCenter:'',

    // DataStore
    dsItems:'',
    dsItemDesc:'',

    // Window
    winAbout:false,

    // Task
    TaskSearchFeed:false,
    TaskCleanFeed:false,

    // others vars
    FeedNeedUpdate:false,
    LastClick:0,
    curNodeId:'',
    curFeedId:'',
    columnUnseenWidth:50, // change this value to modify Unseen column width
    columnTotalWidth:50, // change this value to modify Total column width
    linkDefaultTab:'',

    init: function(){
        this.launcher = {
            text: 'Desk-Kregator',
            tooltip: '<b>Desk-Kregator</b><br />' + DeskKregator.LauncherDescription,
            iconCls: 'DeskKregator-icon',
            shortcutIconCls: 'DeskKregator-win-shortcut',
            handler: this.createWindow,
            scope: this
        };
    },

    createWindow: function() {
        var desktop = this.app.getDesktop();
        var win = desktop.getWindow('DeskKregator-win');

        if (!win) {

             // Plugins for right click on tab
             Ext.ux.KregaTabCloseMenu = function(env){
                 var tabs, menu, ctxItem;
                 this.scope = env;
                 this.init = function(tp){
                     tabs = tp;
                     tabs.on('contextmenu', onContextMenu, this);
                 };

                 function onContextMenu(ts, item, e){

                     if( item.id == 'DeskKregator-main' ) { item.linkTab = this.scope.linkDefaultTab;}

                     if(!menu){ // create context menu on first right click
                         menu = new Ext.menu.Menu([{
                             id: 'DeskKregator-' + tabs.id + '-close',
                             text: DeskKregator.TabCtxCloseTab,
                             iconCls: 'DeskKregator-close-Tab-btn',
                             handler : function() {
                                 tabs.remove(ctxItem);
                             }
                         },{
                             id: 'DeskKregator-' + tabs.id + '-close-others',
                             text: DeskKregator.TabCtxCloseOtherTabs,
                             handler : function() {
                                 tabs.items.each(function(item){
                                     if(item.closable && item != ctxItem){
                                         tabs.remove(item);
                                     }
                                 });
                             }
                         },'-',{
                             id:'DeskKregator-' + tabs.id + '-open-tab-site',
                             text:DeskKregator.FeedGridItemOpenInWin,
                             iconCls:'DeskKregator-open-site-btn',
                             handler: function() {
                              window.open(ctxItem.linkTab, 'win');
                             }
                         }]);
                     }
                     ctxItem = item;
                     var items = menu.items;
                     items.get('DeskKregator-' + tabs.id + '-close').setDisabled(!item.closable);
                     var disableOthers = true;
                     tabs.items.each(function(){
                         if(this != item && this.closable){
                             disableOthers = false;
                             return false;
                         }
                     });
                     items.get('DeskKregator-' + tabs.id + '-close-others').setDisabled(disableOthers);
                     if( !item.linkTab ) {
                        items.get('DeskKregator-' + tabs.id + '-open-tab-site').setDisabled(true);
                     } else {
                        items.get('DeskKregator-' + tabs.id + '-open-tab-site').setDisabled(false);
                     }
                     menu.showAt(e.getPoint());
                 }
             };

             // Custom ColumnTree
             Ext.tree.KregaColumnTree = Ext.extend(Ext.tree.TreePanel, {
                 lines:false,
                 borderWidth: Ext.isBorderBox ? 0 : 2, // the combined left/right border for each cell
                 cls:'DeskKregator-x-column-tree',

                 onRender : function(){
                     Ext.tree.KregaColumnTree.superclass.onRender.apply(this, arguments);
                     this.headers = this.body.createChild(
                         {id:'DeskKregator-x-tree-headers-id', cls:'DeskKregator-x-tree-headers'},this.innerCt.dom);

                     var cols = this.columns, c;
                     var totalWidth = 0;

                     for(var i = 0, len = cols.length; i < len; i++) {

                          var clsHere;

                          if( i === 0 ) { clsHere = 'DeskKregator-x-tree-hd-text-feed';}
                          else  { clsHere = 'DeskKregator-x-tree-hd-text';}

                          c = cols[i];
                          totalWidth += c.width;
                          this.headers.createChild({
                              id: 'DeskKregator-feed-hd-'+i,
                              cls:'DeskKregator-x-tree-hd ' + (c.cls?c.cls+'-hd':''),
                              cn: {
                                  cls: clsHere,
                                  html: c.header
                              },
                              style:'width:'+(c.width-this.borderWidth)+'px;'
                          });
                     }
                     this.headers.createChild({cls:'x-clear'});
                     // prevent floats from wrapping when clipped
                     this.headers.setWidth(totalWidth);
                     this.innerCt.setWidth(totalWidth);
                 }
             });

             Ext.tree.KregaColumnNodeUI = Ext.extend(Ext.tree.TreeNodeUI, {
                 focus: Ext.emptyFn, // prevent odd scrolling behavior

                 renderElements : function(n, a, targetNode, bulkRender){
                     this.indentMarkup = n.parentNode ? n.parentNode.ui.getChildIndent() : '';

                     var t = n.getOwnerTree();
                     var cols = t.columns;
                     var bw = t.borderWidth;
                     var c = cols[0];
                     var colID;

                     var buf = [
                          '<li class="x-tree-node"><div ext:tree-node-id="',n.id,'" class="x-tree-node-el x-tree-node-leaf ', a.cls,'">',
                             '<div class="DeskKregator-x-tree-col" style="width:',c.width-bw,'px;">',
                                 '<span class="x-tree-node-indent">',this.indentMarkup,"</span>",
                                 '<img src="', this.emptyIcon, '" class="x-tree-ec-icon x-tree-elbow">',
                                 '<img src="', a.icon || this.emptyIcon, '" class="x-tree-node-icon',(a.icon ? " x-tree-node-inline-icon" : ""),(a.iconCls ? " "+a.iconCls : ""),'" unselectable="on">',
                                 '<a hidefocus="on" class="x-tree-node-anchor" href="',a.href ? a.href : "#",'" tabIndex="1" ',
                                 a.hrefTarget ? ' target="'+a.hrefTarget+'"' : "", '>',
                                 '<span unselectable="on">', n.text || (c.renderer ? c.renderer(a[c.dataIndex], n, a) : a[c.dataIndex]),"</span></a>",
                             "</div>"];
                      for(var i = 1, len = cols.length; i < len; i++) {
                          c = cols[i];

                          if( i == 1 ) { colID = 'DeskKregator-unSeen-'+n.id; }
                          else { colID = 'DeskKregator-Total-'+n.id; }

                          buf.push('<div class="DeskKregator-x-tree-col ',(c.cls?c.cls:''),'" style="width:',c.width-bw,'px;">',
                                     '<div class="DeskKregator-x-tree-col-text" id="'+colID+'">',(c.renderer ? c.renderer(a[c.dataIndex], n, a) : a[c.dataIndex]),"</div>",
                                   "</div>");
                      }
                      buf.push(
                         '<div class="x-clear"></div></div>',
                         '<ul class="x-tree-node-ct" style="display:none;"></ul>',
                         "</li>");

                     if(bulkRender !== true && n.nextSibling && n.nextSibling.ui.getEl()){
                         this.wrap = Ext.DomHelper.insertHtml("beforeBegin",
                                             n.nextSibling.ui.getEl(), buf.join(""));
                     }else{
                         this.wrap = Ext.DomHelper.insertHtml("beforeEnd", targetNode, buf.join(""));
                     }

                     this.elNode = this.wrap.childNodes[0];
                     this.ctNode = this.wrap.childNodes[1];
                     var cs = this.elNode.firstChild.childNodes;
                     this.indentNode = cs[0];
                     this.ecNode = cs[1];
                     this.iconNode = cs[2];
                     this.anchor = cs[3];
                     this.textNode = cs[3].firstChild;
                 }
             });

            // Create Splash
            Ext.DomHelper.append(document.body, {
                tag: 'div',
                id: 'DeskKregator-splash',
                children: [{
                    tag: 'div',
                    cls: 'DeskKregator-splash-indicator',
                    html: '<img src="system/modules/Desk-Kregator/img/default/splash.png" alt="" /><div id="DeskKregator-splash-msg">' + DeskKregator.SplashInit + '</div>'
                }]
            });

            this.dsItems = new Ext.data.Store({
                proxy: new Ext.data.HttpProxy({
                    url: this.app.connection+'?moduleId='+this.moduleId+'&fileName=php/desk-kregator.php&what=get_items'
                }),
                reader: new Ext.data.JsonReader({
                    root: 'Items',
                    totalProperty: 'nbItems',
                    id: 'id'
                }, [{
                    name: 'id',
                    mapping: 'id'
                }, {
                    name: 't',
                    mapping: 't'
                }, {
                    name: 'd',
                    mapping: 'd'
                }, {
                    name: 'u',
                    mapping: 'u'
                }, {
                    name: 's',
                    mapping: 's'
                }, {
                    name: 'i',
                    mapping: 'i'
                }, {
                    name: 'f',
                    mapping: 'f'
                }, {
                    name: 'id_f',
                    mapping: 'id_f'
                }, {
                    name: 'sum',
                    mapping: 'sum'
                }])
            });

            // Sort by default : date, DESC
            this.dsItems.setDefaultSort('d', 'desc');

            this.dsItems.on('load', function(){
                this.setStatusBar('DeskKregator-done', DeskKregator.StatutDone);
                this.selectFirstUnreadItems();

            }, this);

            this.dsItemDesc = new Ext.data.Store({
                proxy: new Ext.data.HttpProxy({
                    url: this.app.connection
                }),
                baseParams: {
                    moduleId: this.moduleId,
                    fileName: 'php/desk-kregator.php',
                    what: 'get_items_desc'


                },
                reader: new Ext.data.JsonReader({}, [{
                    name: 't'
                }, {
                    name: 'd'
                }, {
                    name: 'a'
                }, {
                    name: 'des'
                }, {
                    name: 'u'
                }, {
                    name: 'f'
                }])
            });

            this.dsItemDesc.on('load', function(){

                var nodeItem = this.dsItemDesc.getAt(0);
                var title = nodeItem.data.t;
                var link = nodeItem.data.u;
                var date = this.renderDate(nodeItem.data.d);
                var auteur = nodeItem.data.a;
                var feedName = nodeItem.data.f;
                var desc = nodeItem.data.des;

                if (this.PanelFeedTree.selModel.selNode.attributes.view == 'site') {

                    this.PanelPreview.setTitle(this.PanelFeedTree.selModel.selNode.attributes.text);
                    this.PanelPreview.body.dom.innerHTML = '<div class="DeskKregator-preview-content"><iframe width="100%" height="100%" frameborder="0" src="' + link + '" /></div>';

                }
                else {

                    this.PanelPreview.setTitle(feedName);

                    var content = '<div class="DeskKregator-feed-info">' +
                    '<div class="DeskKregator-item-date">' +
                    date +
                    '</div>' +
                    '<div class="DeskKregator-item-title">' +
                    title +
                    '</div>' +
                    '<div class="DeskKregator-item-author">' +
                    DeskKregator.PreviewAutor +
                    auteur +
                    '</div>' +
                    '</div>' +
                    '<div class="DeskKregator-feed-content">' +
                    desc +
                    '</div>';

                    this.PanelPreview.body.dom.innerHTML = content;
                    this.PanelPreview.el.on('click', function(e, target, options){

                        e.preventDefault();
                        e.stopEvent();

                        var delai = new Date();
                        var curClick = delai.getTime();

                        if (this.LastClick == 0) { this.LastClick = curClick - 51; }

                        var diff = (curClick - this.LastClick);
                        if (target.href) {
                            if (diff > 50) {
                                this.LastClick = curClick;
                                var uniq = Ext.id();
                                this.openInTab(uniq, target.href, target.href);
                            }
                        }
                    }, this);
                }

                this.setStatusBar('DeskKregator-done', DeskKregator.StatutDone);

            }, this);

            this.PanelFeedTree = new Ext.tree.KregaColumnTree({
                    width:252,
                    id: 'DeskKregator-id-tree-column',
                    border: false,
                    enableDD: true,
                    autoHeight:true,
                    rootVisible:false,
                    autoScroll:true,
                    containerScroll: true,
                    listeners: {
                        scope: this,
                        contextmenu: this.onContextMenuFeed,
                        click: this.onClickFeed
                    },

                    columns:[{
                        id:'DeskKregator-feedTree-colum',
                        header:DeskKregator.TreeTitle,
                        width:150,
                        dataIndex:'text'
                    },{
                        header: DeskKregator.TreeColumn1,
                        width:this.columnUnseenWidth,
                        dataIndex:'unseen'
                    },{
                        header: DeskKregator.TreeColumn2,
                        width:this.columnTotalWidth,
                        dataIndex:'total'
                    }],

                    loader: new Ext.tree.TreeLoader({
                        dataUrl:this.app.connection+'?moduleId='+this.moduleId+'&fileName=php/desk-kregator.php&what=get_nodes',
                        uiProviders:{
                            'col': Ext.tree.KregaColumnNodeUI
                        }
                    }),

                    root: new Ext.tree.AsyncTreeNode({
                        text:'RootFeed'
                    })
            });

            // Editor
            this.PanelFeedTreeEditor = new Ext.tree.TreeEditor(this.PanelFeedTree, {
                allowBlank: false
            });

            // Edit node
            this.PanelFeedTreeEditor.on('complete', function(editor, fieldValue, beforeValue){

                // If there is no change, go back
                if(fieldValue == beforeValue) { return; }

                this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutMod);

                // Update nodeText
                var saveFeedText = new Ext.data.Connection();
                saveFeedText.request({
                    scope: this,
                    url: this.app.connection,
                    params: {
                        moduleId: this.moduleId,
                        fileName: 'php/desk-kregator.php',
                        id: editor.editNode.id,
                        value: fieldValue,
                        what: 'mod_feed_text'
                    },

                    success: function(response, options){

                        var o = Ext.util.JSON.decode(response.responseText);

                        if (o.success) {
                            this.setStatusBar('DeskKregator-done', DeskKregator.StatutModOk);

                            // Update tab title & preview Title
                            Ext.getCmp('DeskKregator-main').setTitle(fieldValue.ellipse(20));
                            this.PanelPreview.setTitle(fieldValue);

                        }
                        else {
                            this.setStatusBar('DeskKregator-done', DeskKregator.StatutModNok);
                        }
                    }
                });

            }, this);

            // Drag & Drop Tree Elements
            this.PanelFeedTree.on('enddrag', function(tree){

                this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutReorder);

                function simplifyNodes(node){
                    var resultNode = {};
                    var kids = node.childNodes;
                    var len = kids.length;
                    for (var i = 0; i < len; i++) {
                        resultNode[kids[i].id] = simplifyNodes(kids[i]);
                    }
                    return resultNode;
                }

                // JSON-encode our tree
                var encNodes = Ext.encode(simplifyNodes(this.PanelFeedTree.root));

                // send it to the backend to save
                var saveOrder = new Ext.data.Connection();
                saveOrder.request({
                    scope: this,
                    url: this.app.connection,
                    params: {
                        moduleId: this.moduleId,
                        fileName: 'php/desk-kregator.php',
                        nodes: encNodes,
                        what: 'save_nodes'
                    },

                    success: function(response, options){

                        var o = Ext.util.JSON.decode(response.responseText);

                        if (o.success) {
                            this.setStatusBar('DeskKregator-done', DeskKregator.StatutReorderOk);
                        }
                        else {
                            this.setStatusBar('DeskKregator-error', DeskKregator.StatutReorderNok);
                        }
                    }
                });
            }, this);

            // New SearchField
            Ext.app.SearchField = Ext.extend(Ext.form.TwinTriggerField, {

                initComponent: function(){

                    if (!this.store.baseParams) {
                        this.store.baseParams = {};
                    }

                    Ext.app.SearchField.superclass.initComponent.call(this);

                    this.on('specialkey', function(f, e){
                        if (e.getKey() == e.ENTER) {
                            this.onTrigger2Click();
                        }
                    }, this);
                },

                validationEvent: false,
                validateOnBlur: false,
                trigger1Class: 'x-form-clear-trigger',
                trigger2Class: 'x-form-search-trigger',
                hideTrigger1: true,
                width: 100,
                hasSearch: false,
                emptyText: DeskKregator.FeedGridFilterSearch,

                onTrigger1Click: function(){
                    if (this.hasSearch) {

                        this.store.baseParams = {
                            'id_feed': this.env.curFeedId,
                            'id_node': this.env.curNodeId
                        };

                        Ext.getCmp('DeskKregator-etat').setValue('all', true);

                        var o = {
                            start: 0,
                            limit: 25
                        };
                        this.store.reload({
                            params: o
                        });

                        this.el.dom.value = '';
                        this.triggers[0].hide();
                        this.hasSearch = false;
                        //this.focus();
                    }
                    this.reset();
                },

                onTrigger2Click: function(){

                    var v = this.getRawValue();

                    if (v.length < 2 && v != '') {
                        Ext.Msg.alert(DeskKregator.FeedGridBoxSearchTitle, DeskKregator.FeedGridBoxSearchContent);
                        return;
                    }

                    this.env.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutSearchLoad);

                    this.store.baseParams = {
                        'id_feed': this.env.curFeedId,
                        'id_node': this.env.curNodeId,
                        'searchText': v,
                        'searchEtat': Ext.getCmp('DeskKregator-etat').getValue()
                    };

                    var o = {
                        start: 0,
                        limit: 25
                    };
                    this.store.reload({
                        params: o
                    });
                    this.hasSearch = true;
                    this.triggers[0].show();
                    //this.focus();
                }
            });

            // End new searchField

            this.PanelGridItem = new Ext.grid.GridPanel({
                scope: this,
                id:'DeskKregator-id-gridFeed-panel',
                store: this.dsItems,
                lastRowClick: {
                    time: new Date().getTime(),
                    row: -1
                },
                columns: [{
                    id: 'article',
                    header: DeskKregator.FeedGridHeaderItem,
                    sortable: true,
                    dataIndex: 't'
                }, {
                    id: 'feed',
                    header: DeskKregator.FeedGridHeaderFeed,
                    sortable: true,
                    width: 120,
                    dataIndex: 'f'
                }, {
                    id: 'date',
                    header: DeskKregator.FeedGridHeaderDate,
                    width: 120,
                    sortable: true,
                    dataIndex: 'd',
                    renderer: this.renderDate
                }],
                autoExpandColumn: 'article',
                loadMask: true,
                viewConfig: {
                    scope: this,
                    forceFit: true,
                    showSummary: this.ConfShowSummary,
                    enableRowBody: true,
                    getRowClass: function(record, rowIndex, p, ds) {

                        var retour = '';

                        if (record.data.s == 'y') {
                            retour += 'DeskKregator-feed-read';
                        } else {
                            retour += 'DeskKregator-feed-unread';
                        }

                        if (record.data.i == 'y') {
                            retour += ' DeskKregator-feed-important';
                        }

                        if( this.showSummary ) {
                            p.body = '<p class="DeskKregator-summary">' + record.data.sum + '</p>';
                            retour += ' x-grid3-row-expanded';
                        }

                        return retour;

                    }
                },
                enableColumnMove: true,
                tbar: [new Ext.app.SearchField({
                    id: 'DeskKregator-search',
                    width: 130,
                    store: this.dsItems,
                    env: this,
                    listeners: {
                     scope: this
                    }
                }), '-', {
                    xtype: 'combo',
                    store: new Ext.data.SimpleStore({
                        fields: ['etat', 'Libel'],
                        data: [['all', DeskKregator.FeedGridFilterAllItems], ['nonlu', DeskKregator.FeedGridFilterUnseenItems], ['important', DeskKregator.FeedGridFilterImportantItems]]
                    }),
                    displayField: 'Libel',
                    valueField: 'etat',
                    typeAhead: true,
                    width: 120,
                    mode: 'local',
                    triggerAction: 'all',
                    selectOnFocus: false,
                    editable: false,
                    allowBlank: false,
                    value: 'all',
                    id: 'DeskKregator-etat',
                    listeners: {
                        scope: this,
                        select: function(){
                            Ext.getCmp('DeskKregator-search').onTrigger2Click();
                        }
                    }
                }, '-', {
                    scope: this,
                    tooltip: {
                        title: DeskKregator.ReadingBtnTitle,
                        text: DeskKregator.ReadingBtnQtip
                    },
                    iconCls: 'DeskKregator-preview-bottom',
                    handler: this.movePreview

                }, '-', {
                    scope: this,
                    tooltip: {
                        title: DeskKregator.SummaryBtnTitle,
                        text: DeskKregator.SummaryBtnText
                    },
                    enableToggle: true,
                    id:'DeskKregator-summary-btn-id',
                    iconCls: 'DeskKregator-summary-btn',
                    toggleHandler: function(btn, pressed){
                      this.toggleSummary(pressed);
                    }
                }],

                bbar: new Ext.PagingToolbar({
                    pageSize: 25,
                    store: this.dsItems,
                    displayInfo: true,
                    displayMsg: DeskKregator.FeedGridPagingDisplay,
                    emptyMsg: DeskKregator.FeedGridPagingNoDisplay
                }),
                listeners: {
                    scope: this,
                    rowdblclick: function(grid, rowIndex, e) {

                        var _node = this.dsItems.getAt(rowIndex);
                        var _id = _node.data.id;
                        var _link = _node.data.u;
                        var _title = _node.data.t;
                        this.openInTab('items-' + _id, _title, _link);

                        var timeNow = new Date().getTime();

                        if(grid.lastRowClick.row != rowIndex){
                            grid.lastRowClick.row = rowIndex;
                            grid.lastRowClick.time = timeNow;
                        }
                        else if(timeNow - grid.lastRowClick.time >= 500){
                            return;
                        }
                        else{
                            grid.lastRowClick.time = timeNow;
                        }

                    },

                    rowclick: function(grid, rowIndex, e) {

                        var timeNow = new Date().getTime();
                        if(grid.lastRowClick.row != rowIndex){
                            grid.lastRowClick.row = rowIndex;
                            grid.lastRowClick.time = timeNow;
                        }
                        else if(timeNow - grid.lastRowClick.time < 500){
                            return;
                        }
                        else{
                            grid.lastRowClick.time = timeNow;
                        }

                    },

                    rowcontextmenu: function(grid, rowIndex, e){
                        this.onContextItemFeed(grid, rowIndex, e);
                    }
                }
            });

            // SelectionModel for GridPanel
            var smPanelGridItem = this.PanelGridItem.getSelectionModel();
            smPanelGridItem.on('rowselect', function(sM, rowIndex, r) {

               this.loadItem(rowIndex);

            }, this);

            this.PanelCenter = new Ext.TabPanel({
                region: 'center',
                margins: '0 0 0 0',
                activeTab: 0,
                border: false,
                bodyStyle: 'background-color:#fff',
                enableTabScroll: true,
                plugins: new Ext.ux.KregaTabCloseMenu(this),
                defaults: {
                    autoScroll: true
                },
                items: [{
                    title: DeskKregator.FeedGridTabTitle,
                    id: 'DeskKregator-main',
                    border: false,
                    margins: '0 0 0 0',
                    layout: 'fit',
                    items: [{
                        region: 'center',
                        border: false,
                        layout: 'border',
                        margins: '0 0 0 0',
                        items: [{
                            region: 'center',
                            layout: 'fit',
                            border: false,
                            minHeight: 150,
                            height: 150,
                            split: true,
                            items: this.PanelGridItem
                        }, {
                            autoScroll: true,
                            layout: 'fit',
                            region: 'south',
                            split: true,
                            height: 300,
                            bodyStyle: 'background-color:#fff',
                            id: 'DeskKregator-previewPanelSouth',
                            title: DeskKregator.PreviewTitle
                        }, {
                            autoScroll: true,
                            layout: 'fit',
                            region: 'east',
                            split: true,
                            hidden: true,
                            width: 400,
                            bodyStyle: 'background-color:#fff',
                            id: 'DeskKregator-previewPanelEast',
                            title: DeskKregator.PreviewTitle
                        }]
                    }]
                }]
            });

            this.PanelPreview = Ext.getCmp('DeskKregator-previewPanelSouth');

            var winWidth = desktop.getWinWidth() / 1.1;
            var winHeight = desktop.getWinHeight() / 1.1;

            win = desktop.createWindow({
                id: 'DeskKregator-win',
                title: 'Desk-Kregator',
                width: winWidth,
                height: winHeight,
                x: desktop.getWinX(winWidth),
                y: desktop.getWinY(winHeight),
                iconCls: 'DeskKregator-icon',
                shim: false,
                animCollapse: false,
                constrainHeader: true,
                minimizable: true,
                maximizable: true,
                layout: 'border',
                tools : [{
                  scope: this,
                  id:'gear',
                  qtip:DeskKregator.WinConfToolTip,
                  handler:this.showConf

                }, {
                  scope: this,
                  id:'help',
                  qtip: DeskKregator.WinAboutTitle,
                  handler:this.showAbout

                }],
                bbar: new Ext.StatusBar({
                          id: 'DeskKregator-statusBar',
                          text: DeskKregator.StatutReady,
                          iconCls: 'DeskKregator-done'

                }),
                items: [{
                    region: 'west',
                    layout:'fit',
                    id: 'DeskKregator-id-Feed-Tree',
                    autoScroll: true,
                    collapsible: true,
                    collapseMode: 'mini',
                    cmargins: '0 0 0 0',
                    margins: '0 0 0 0',
                    split: true,
                    bodyStyle: 'background-color:#fff',
                    width: 254,
                    items: this.PanelFeedTree,
                    scope: this,
                    tbar: [{
                        id: 'DeskKregator-add-feed-btn',
                        iconCls:'DeskKregator-icon-add-feed',
                        cls: 'x-btn-icon',
                        scope: this,
                        handler: function(){
                            this.showAddFeed(0);
                        },
                        tooltip: DeskKregator.TreeAddFeed
                    }, {
                        iconCls:'DeskKregator-icon-add-folder',
                        scope: this,
                        handler: function(){
                            this.showAddFolder(0);
                        },
                        tooltip: DeskKregator.TreeAddFolder
                    }, {
                        iconCls:'DeskKregator-icon-import',
                        scope: this,
                        handler: this.showImport,
                        tooltip: DeskKregator.TreeImport
                    }, {
                        scope: this,
                        iconCls:'DeskKregator-icon-export',
                        handler: function(){
                            window.location = this.app.connection+'?moduleId='+this.moduleId+'&fileName=php/export.php';
                        },
                        tooltip: DeskKregator.TreeExport
                    }, {
                        scope: this,
                        id: 'DeskKregator-expand-collapse-btn',
                        iconCls:'DeskKregator-icon-expand',
                        handler: function(){
                           if( !this.ConfExpandCollapse ) {

                             this.ConfExpandCollapse='collapse';
                             this.PanelFeedTree.expandAll();
                             Ext.getCmp('DeskKregator-expand-collapse-btn').setIconClass('DeskKregator-icon-collapse');

                           } else if( this.ConfExpandCollapse == 'expand' ) {

                             this.ConfExpandCollapse='collapse';
                             this.PanelFeedTree.expandAll();
                             Ext.getCmp('DeskKregator-expand-collapse-btn').setIconClass('DeskKregator-icon-collapse');

                           } else if( this.ConfExpandCollapse == 'collapse' ) {

                             this.ConfExpandCollapse='expand';
                             this.PanelFeedTree.collapseAll();
                             Ext.getCmp('DeskKregator-expand-collapse-btn').setIconClass('DeskKregator-icon-expand');

                           }
                        },
                        tooltip: 'Expand all / Collapse all'
                    }, {
                        scope:this,
                        id: 'DeskKregator-add-refresh-feed-btn',
                        iconCls: 'DeskKregator-refresh-btn',
                        handler: function(){
                            this.TaskSearchFeed.delay(1000);
                        },
                        tooltip: DeskKregator.TreeRefresh
                    }]
                }, this.PanelCenter]
            });


            // We load user conf before show app
            Ext.get('DeskKregator-splash-msg').dom.innerHTML = DeskKregator.SplashLoadConf;


            Ext.Ajax.request({
                scope: this,
                url: this.app.connection,
                params: {
                    moduleId: this.moduleId,
                    fileName: 'php/desk-kregator.php',
                    what: 'get_user_conf'
                },
                success: function(response, options){

                    var o = Ext.util.JSON.decode(response.responseText);

                    if (o.success) {

                        this.ConfRefreshFeed = o.refresh_feed;
                        this.ConfOldItems = o.old_items;
                        this.ConfOldItemsDay = o.old_items_day;
                        this.ConfPreviewPane = o.preview_pane;
                        this.ConfShowSummary = o.showSummary;

                        this.ConfTreePanelWidth = o.tree_panel_width;
                        this.ConfGridPanelHeight = o.grid_panel_height;
                        this.ConfPreviewPanelSouthHeight = o.preview_panel_south_height;
                        this.ConfPreviewPanelEastWidth = o.preview_panel_east_width;

                    }
                    else {

                        this.ConfRefreshFeed = 10;
                        this.ConfOldItems = false;
                        this.ConfOldItemsDay = 30;
                        this.ConfPreviewPane = 'bottom';
                        this.ConfShowSummary = true;

                        this.ConfTreePanelWidth = '254';
                        this.ConfGridPanelHeight = '150';
                        this.ConfPreviewPanelSouthHeight = '300';
                        this.ConfPreviewPanelEastWidth = '400';

                    }

                    // Continue
                    Ext.get('DeskKregator-splash').fadeOut({
                        remove: true
                    });

                    win.show();

                    this.PanelFeedTree.on('collapsenode', function(node){ this.saveFolderState(node.id, 0); }, this);
                    this.PanelFeedTree.on('expandnode', function(node){ this.saveFolderState(node.id, 1); }, this);

                    // Set preview pane position
                    this.setPreviewPanePosition(this.ConfPreviewPane);

                    // Set summary configuration
                    this.setSummary(this.ConfShowSummary);

                    // Set Pane Size
                    this.setPanelSize('tree_panel_width',  this.ConfTreePanelWidth);
                    this.setPanelSize('grid_panel_height', this.ConfGridPanelHeight);
                    this.setPanelSize('panel_south_height',this.ConfPreviewPanelSouthHeight);
                    this.setPanelSize('panel_east_width',  this.ConfPreviewPanelEastWidth);

                    if (this.ConfOldItems) {

                        // Register task for delete old items
                        this.TaskCleanFeed = new Ext.util.DelayedTask(this.cleanFeed, this);
                        this.TaskCleanFeed.delay(2000); // start after 2 secondes.
                    }
                    else {

                        // Register task for AutoRefresh Feed
                        this.TaskSearchFeed = new Ext.util.DelayedTask(this.searchFeed, this);
                        this.TaskSearchFeed.delay(2000); // start after 2 secondes.
                    }

                    //this.selectFirstUnseenFeed();

                    var Krega_taskSelectFirstFeed = new Ext.util.DelayedTask(this.selectFirstUnseenFeed, this);
                    Krega_taskSelectFirstFeed.delay(1000); // start after 1 seconde.

                    this.setStatusBar('DeskKregator-done', DeskKregator.StatutReady);

                    // 'On' resize TreePanel
                    Ext.getCmp('DeskKregator-id-Feed-Tree').on('resize', function(panel, Pwidth, Pheight) {

                      var treeWidth;

                      if( panel.body.isScrollable() ) { treeWidth = Pwidth-19; }
                      else { treeWidth = Pwidth; }

                      this.setFeedPanelWidth(treeWidth);
                      this.savePanelSizeState('tree_panel_width', treeWidth);

                    }, this);

                    // 'On' resize GridPanel
                    Ext.getCmp('DeskKregator-id-gridFeed-panel').on('resize', function(panel, Pwidth, Pheight) {
                       this.savePanelSizeState('grid_panel_height', Pheight);
                    }, this);

                    // 'On' resize PreviewPanel Bottom
                    Ext.getCmp('DeskKregator-previewPanelSouth').on('resize', function(panel, Pwidth, Pheight) {
                     this.savePanelSizeState('preview_panel_south_height', Pheight);
                    }, this);

                    // 'On' resize PreviewPanel Right
                    Ext.getCmp('DeskKregator-previewPanelEast').on('resize', function(panel, Pwidth, Pheight) {
                     this.savePanelSizeState('preview_panel_east_width', Pwidth);
                    }, this);

                }

            });
        }
        else { win.show(); }

        // Unregister
        win.on('close', function() { this.TaskSearchFeed.cancel(); }, this);

    }, //createWindow

    selectFirstUnreadItems: function() {

     var firstItem = false;
     var firstItemUnread = false;
     var rowIndex = 0;

     // We loop over items
     for( var i = 0 ; i < this.dsItems.data.length ; i++ ) {

       // State first items
       if( i == 0 ) { firstItem = this.dsItems.data.items[i].data.id; }

       // State first items unread
       if( this.dsItems.data.items[i].data.s == 'n' ) {
        firstItemUnread = this.dsItems.data.items[i].data.id;
        rowIndex = i;
        break;
       }
     }

     if( firstItemUnread ) {

      // Load first unread
      this.PanelGridItem.getSelectionModel().selectRow(rowIndex);

      this.loadItem(rowIndex);
     } else if( firstItem ) {

      // or load first item
      this.PanelGridItem.getSelectionModel().selectRow(rowIndex);
      this.loadItem(rowIndex);
     }

    }, // selectFirstUnreadItems

    selectFirstUnseenFeed: function() {

        var firstFeed = false;
        var firstFolder = false;
        var firstFeedUnread = false;

        function _searchFeed(node){
            var kids = node.childNodes;
            var len = kids.length;
            for (var i = 0; i < len; i++) {

                if (kids[i].attributes.type == 'folder') {
                    if( !firstFolder ) { firstFolder = kids[i].id; }
                }

                if (kids[i].attributes.type == 'file') {

                    if( !firstFeed ) { firstFeed = kids[i].id; }

                    if( kids[i].attributes.unseen != '-' && kids[i].attributes.unseen > 0 ) {

                       if( !firstFeedUnread ) {
                        firstFeedUnread = kids[i].id;
                        break;
                       }
                    }

                }
                if( !firstFeedUnread ) { _searchFeed(kids[i]); }
            }
        }

        _searchFeed(this.PanelFeedTree.getRootNode());

        // Select Best Feed
        if( firstFeedUnread ) {
         this.PanelFeedTree.getNodeById(firstFeedUnread).select();
         this.onClickFeed(this.PanelFeedTree.getNodeById(firstFeedUnread));
        } else if( firstFeed ) {
         this.PanelFeedTree.getNodeById(firstFeed).select();
         this.onClickFeed(this.PanelFeedTree.getNodeById(firstFeed));
        } else if( firstFolder ) {
         this.PanelFeedTree.getNodeById(firstFolder).select();
         this.onClickFeed(this.PanelFeedTree.getNodeById(firstFolder));
        }
    },

    loadItem : function(rowIndex) {

        var curArticle = this.dsItems.getAt(rowIndex).data.id;

        this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutLoadFeedArticle + this.dsItems.getAt(rowIndex).data.t);

        this.markAsSeenUnseen('y', curArticle, this);
        var r = Ext.get(this.PanelGridItem.getView().getRow(rowIndex));
        r.replaceClass("DeskKregator-feed-unread", "DeskKregator-feed-read");

        this.dsItemDesc.load({
            params: {
                'id_item': curArticle
            }
        });

    }, // loadItem

    setPanelSize : function(Panel, Psize) {

        switch (Panel) {
            case 'tree_panel_width':
                Ext.getCmp('DeskKregator-id-Feed-Tree').setWidth(Psize);
                this.setFeedPanelWidth(Psize);
                break;
            case 'grid_panel_height':
                Ext.getCmp('DeskKregator-id-gridFeed-panel').setHeight(Psize);
                break;
            case 'panel_south_height':
                Ext.getCmp('DeskKregator-previewPanelSouth').setHeight(Psize);
                break;
            case 'panel_east_width':
                Ext.getCmp('DeskKregator-previewPanelEast').setWidth(Psize);
                break;
        }

    }, // setPanelSize

    savePanelSizeState : function(Panel, Psize) {

            Ext.Ajax.request({
                url: this.app.connection,
                params: {
                  moduleId: this.moduleId,
                  fileName: 'php/desk-kregator.php',
                  panel: Panel,
                  panelsize: Psize,
                  what: 'set_panelsize_state'
                }
            });

    }, //savePanelWidthState

    setFeedPanelWidth : function(treeWidth) {

      var bw = Ext.isBorderBox ? 0 : 2;
      var widths = [(treeWidth-(this.columnUnseenWidth+this.columnTotalWidth+4)), this.columnUnseenWidth, this.columnTotalWidth];
      var totalWidth = 0;
      for (var i = 0; i < widths.length; i++) {
        totalWidth += widths[i];
        Ext.select("div.DeskKregator-x-tree-hd:nth-child(" + (i+1) + ")", false, "*TreeID*").setWidth(widths[i] - bw);
        Ext.select("div.DeskKregator-x-tree-col:nth-child(" + (i+1) + ")", false, "*TreeID*").setWidth(widths[i] - bw);
        this.PanelFeedTree.columns[i].width = widths[i];
      }
      this.PanelFeedTree.headers.setWidth(totalWidth);
      this.PanelFeedTree.innerCt.setWidth(totalWidth);

    }, //setFeedPanelWidth

    setSummary : function(pressed) {

      this.toggleSummary(pressed);
      Ext.getCmp('DeskKregator-summary-btn-id').toggle(pressed);

    }, // setSummary

    toggleSummary : function(pressed) {

       this.PanelGridItem.view.showSummary = pressed;
       this.PanelGridItem.view.refresh();

       // Save in DB
       this.saveSummaryState(pressed);

    }, // toggleSummary

    saveSummaryState:function(state) {

            Ext.Ajax.request({
                url: this.app.connection,
                params: {
                  moduleId: this.moduleId,
                  fileName: 'php/desk-kregator.php',
                  showSummary: state,
                  what: 'set_summary_state'
                }
            });

    }, // saveSummaryState

    saveFolderState:function(_nodeID, expand) {

            Ext.Ajax.request({
                url: this.app.connection,
                params: {
                  moduleId: this.moduleId,
                  fileName: 'php/desk-kregator.php',
                  nodeID: _nodeID,
                  expand: expand,
                  what: 'set_folder_state'
                },
                success: function(response, options){},
                failure: function(response, options){}
            });

    }, // saveFolderState

    movePreview: function() {

        if( this.ConfPreviewPane == 'bottom' ) {
         // Set to right
         this.ConfPreviewPane = 'right';
         this.setPreviewPanePosition('right');

        } else if( this.ConfPreviewPane == 'right' ) {
         //set to hide
         this.ConfPreviewPane = 'hide';
         this.setPreviewPanePosition('hide');

        } else if( this.ConfPreviewPane == 'hide' ) {
         // set to bottom
         this.ConfPreviewPane = 'bottom';
         this.setPreviewPanePosition('bottom');

        }

    }, // movePreview

    setPreviewPanePosition : function(position) {

        var _title = this.PanelPreview.title;
        var _content = this.PanelPreview.body.dom.innerHTML;

        var right = Ext.getCmp('DeskKregator-previewPanelEast');
        var bot = Ext.getCmp('DeskKregator-previewPanelSouth');
        var btn = this.PanelGridItem.getTopToolbar().items.get(4);

        switch (position) {
            case 'bottom':
                this.PanelPreview = bot;
                this.PanelPreview.setTitle(_title);
                this.PanelPreview.body.dom.innerHTML = _content;
                this.PanelPreview.el.on('click',this.clickInterceptor, this);
                right.hide();
                bot.show();
                bot.ownerCt.doLayout();
                btn.setIconClass('DeskKregator-preview-bottom');
                break;
            case 'right':
                this.PanelPreview = right;
                this.PanelPreview.setTitle(_title);
                this.PanelPreview.body.dom.innerHTML = _content;

                this.PanelPreview.el.on('click',this.clickInterceptor, this);

                bot.hide();
                right.show();
                right.ownerCt.doLayout();
                btn.setIconClass('DeskKregator-preview-right');
                break;
            case 'hide':
                this.PanelPreview.hide();
                this.PanelPreview.ownerCt.doLayout();
                btn.setIconClass('DeskKregator-preview-hide');
                break;
        }

        this.savePreviewPanePosition(position);

    }, // setPreviewPanePosition

    savePreviewPanePosition:function(state) {

            Ext.Ajax.request({
                url: this.app.connection,
                params: {
                  moduleId: this.moduleId,
                  fileName: 'php/desk-kregator.php',
                  preview_pane: state,
                  what: 'set_previewpaneposition_state'
                }
            });

    }, // savePreviewPanePosition

    updateFeedInfo : function(id_feed, nb_unseen, nb_total) {

     if( nb_total == 0 ) { nb_total = '-'; }


     if( nb_unseen == 0 ) {
       // Remove class bold
       nb_unseen = '-';
       this.PanelFeedTree.getNodeById(id_feed).ui.removeClass("DeskKregator-feed-Unseen");
       Ext.get('DeskKregator-unSeen-'+id_feed).removeClass("DeskKregator-feed-Unseen");
     } else {
       // Add class bold
       this.PanelFeedTree.getNodeById(id_feed).ui.addClass("DeskKregator-feed-Unseen");
       Ext.get('DeskKregator-unSeen-'+id_feed).addClass("DeskKregator-feed-Unseen");
     }

     Ext.get('DeskKregator-unSeen-'+id_feed).dom.innerHTML = nb_unseen;
     Ext.get('DeskKregator-Total-'+id_feed).dom.innerHTML = nb_total;

    }, //updateFeedInfo

    cleanFeed: function(){

        this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutCleanItemsWait);

        Ext.Ajax.request({
            scope: this,
            url: this.app.connection,
            params: {
                moduleId: this.moduleId,
                fileName: 'php/desk-kregator.php',
                day: this.ConfOldItemsDay,
                what: 'clean_feed'
            },
            success: function(response, options){

                var o = Ext.util.JSON.decode(response.responseText);

                if (o.success) {

                    this.setStatusBar('DeskKregator-done', DeskKregator.StatutCleanItemsOk + o.del_items);


                }
                else {

                    this.setStatusBar('DeskKregator-error', DeskKregator.StatutCleanItemsNok + o.msg);

                }

                // Register task for AutoRefresh Feed after cleanFeed
                this.TaskSearchFeed = new Ext.util.DelayedTask(this.searchFeed, this);
                this.TaskSearchFeed.delay(2000); // start after 2 secondes.
            }
        });

    }, // cleanFeed

    clickInterceptor : function(e, target, options){

        e.preventDefault();
        e.stopEvent();

        var delai = new Date();
        var curClick = delai.getTime();

        if (this.LastClick == 0) {
            this.LastClick = curClick - 51;
        }

        var diff = (curClick - this.LastClick);

        if (target.href) {
            if (diff > 50) {
                this.LastClick = curClick;
                var uniq = Ext.id();
                this.openInTab(uniq, target.href, target.href);
            }
        }

    }, // clickInterceptor

    /********
     *
     * ContextMenu
     *
     ********/
    onContextMenuFeed: function(node, ev){

        ev.preventDefault();
        ev.stopEvent();

        var actuNode = this.PanelFeedTree.getSelectionModel().getSelectedNode();

        if (node != actuNode) {
            node.select();
            this.onClickFeed(node, ev);
        }

        this.curNodeId = node.id;

        var thisNode = node;
        var valeur = node.attributes.unseen;
        var nodeType = node.attributes.type;
        var nodeText = node.attributes.text;
        var IDnode = node.attributes.id;
        var menu;

        if (this.curNodeId != 0) {
            if (nodeType == 'file') {
                menu = new Ext.menu.Menu({
                    items: [{
                        text: DeskKregator.TreeFeedMarkAsRead,
                        iconCls: 'DeskKregator-icon-mark-all-as-read',
                        scope: this,
                        handler: function(el, ev){
                            this.markAllAsRead(thisNode, this);
                        }
                    }, new Ext.menu.Separator(), {
                        scope: this,
                        text: DeskKregator.TreeFeedLoadFeed,
                        iconCls:'DeskKregator-refresh-btn',
                        handler: function(node, ev){
                            this.updateFeed(nodeText, IDnode, this.curNodeId, 'off', -1);
                        }
                    }, new Ext.menu.Separator(), {
                        scope: this,
                        text: DeskKregator.TreeFeedOpenSite,
                        iconCls: 'DeskKregator-open-site-btn',
                        handler: function(node, ev){
                            this.openInTab(thisNode.attributes.id, thisNode.attributes.text, thisNode.attributes.url);
                        }
                    }, new Ext.menu.Separator(), {
                        scope: this,
                        text: DeskKregator.TreeFeedMod,
                        iconCls: 'DeskKregator-icon-mod-feed',
                        handler: function(node, ev){
                            this.showModFeed(thisNode);
                        }
                    }, {
                        scope: this,
                        text: DeskKregator.TreeFeedDel,
                        iconCls: 'DeskKregator-icon-del-feed',
                        handler: function(node, ev){
                            this.showDelItemArbre(thisNode);
                        }
                    }]
                });
                menu.showAt(ev.getXY());
            }

            if (nodeType == 'folder') {
                menu = new Ext.menu.Menu({
                    items: [{
                        scope: this,
                        text: DeskKregator.TreeAddNewFeed,
                        iconCls:'DeskKregator-icon-add-feed',
                        handler: function(node, ev){
                            this.showAddFeed(thisNode.id);
                        }
                    }, {
                        scope: this,
                        text: DeskKregator.TreeAddNewFolder,
                        iconCls: 'DeskKregator-icon-add-folder',
                        handler: function(node, ev){
                            this.showAddFolder(thisNode.id);
                        }
                    }, '-', {
                        scope: this,
                        text: DeskKregator.TreeFolderMod,
                        iconCls: 'DeskKregator-icon-mod-folder',
                        handler: function(node, ev){
                            // Start Edit
                            this.PanelFeedTreeEditor.editNode = thisNode;
                            this.PanelFeedTreeEditor.startEdit(thisNode.ui.getAnchor(), thisNode.text);
                        }
                    }, {
                        scope: this,
                        text: DeskKregator.TreeFolderDel,
                        iconCls: 'DeskKregator-icon-del-folder',
                        handler: function(node, ev){
                            this.showDelItemArbre(thisNode);
                        }
                    }]
                });
                menu.showAt(ev.getXY());
            }
        }
    }, // onContextMenuFeed

    onContextItemFeed: function(grid, rowIndex, ev){

        ev.stopEvent();

        var rowSelected = this.PanelGridItem.getSelections();

        var asSelect = false;
        var contextRowID = this.dsItems.getAt(rowIndex).id;

        for (var i = 0; i < rowSelected.length; i++) {
            if (contextRowID == rowSelected[i].id) {
                asSelect = true;
            }
        }

        if (!asSelect) {
            var v = this.PanelGridItem.getSelectionModel();
            v.selectRow(rowIndex);
            rowSelected = this.PanelGridItem.getSelections();
        }

        var rowDel = '';
        var isImportant = false;

        for (var i = 0; i < rowSelected.length; i++) {

            rowDel += rowSelected[i].id + ',';
            if (rowSelected[i].data.i == 'y') {
                isImportant = true;
            }

        }

        var menu = new Ext.menu.Menu();

        menu.add({
            scope: this,
            text: DeskKregator.FeedGridItemOpenInTab,
            iconCls: 'DeskKregator-open-inTab-btn',
            handler: function(){
                for (var i = 0; i < rowSelected.length; i++) {

                    var _node = this.dsItems.getById(rowSelected[i].id);
                    var _link = _node.data.u;
                    var _title = _node.data.t;

                    this.openInTab('items-' + rowSelected[i].id, _title, _link);
                }
            }
        });

        menu.add({
            scope: this,
            text: DeskKregator.FeedGridItemOpenInWin,
            iconCls: 'DeskKregator-open-site-btn',
            handler: function(){
                for (var i = 0; i < rowSelected.length; i++) {
                    this.openInWindow(rowSelected[i].id);
                }
            }
        });

        menu.addSeparator();

        var varMenuImportant;

        if (isImportant) {

            varMenuImportant = new Ext.menu.Item({
                scope: this,
                text: DeskKregator.FeedGridItemRemoveMarkImportant,
                iconCls: 'DeskKregator-icon-unmark-as-important',
                handler: function(){

                    for (var i = 0; i < rowSelected.length; i++) {
                        this.markAsImportant('n', rowSelected[i].id);

                        var rowId = rowSelected[i].id;
                        var p = Ext.get(this.PanelGridItem.getView().getRow(this.dsItems.indexOfId(rowId)));
                        p.removeClass("DeskKregator-feed-important");
                    }

                }
            });
        }
        else {

            varMenuImportant = new Ext.menu.Item({
                scope: this,
                text: DeskKregator.FeedGridItemMarkAsImportant,
                iconCls: 'DeskKregator-icon-mark-as-important',
                handler: function(){

                    for (var i = 0; i < rowSelected.length; i++) {
                        this.markAsImportant('y', rowSelected[i].id);

                        var rowId = rowSelected[i].id;
                        var p = Ext.get(this.PanelGridItem.getView().getRow(this.dsItems.indexOfId(rowId)));
                        p.addClass("DeskKregator-feed-important");

                    }
                }
            });
        }

        menu.add({
            scope: this,
            text: DeskKregator.FeedGridItemMarkAs,
            menu: {
                items: [varMenuImportant, new Ext.menu.Separator(), new Ext.menu.Item({
                    scope: this,
                    text: DeskKregator.FeedGridItemMarkAsRead,
                    iconCls: 'DeskKregator-icon-mark-as-read',
                    handler: function(){
                        for (var i = 0; i < rowSelected.length; i++) {
                            this.markAsSeenUnseen('y', rowSelected[i].id, this);

                            var rowId = rowSelected[i].id;
                            var p = Ext.get(this.PanelGridItem.getView().getRow(this.dsItems.indexOfId(rowId)));
                            p.addClass("DeskKregator-feed-read");
                            p.removeClass("DeskKregator-feed-unread");

                        }
                    }
                }), new Ext.menu.Item({
                    scope: this,
                    text: DeskKregator.FeedGridItemMarkAsUnRead,
                    iconCls: 'DeskKregator-icon-mark-as-unread',
                    handler: function(){

                        for (var i = 0; i < rowSelected.length; i++) {
                            this.markAsSeenUnseen('n', rowSelected[i].id, this);

                            var rowId = rowSelected[i].id;
                            var p = Ext.get(this.PanelGridItem.getView().getRow(this.dsItems.indexOfId(rowId)));
                            p.removeClass("DeskKregator-feed-read");
                            p.addClass("DeskKregator-feed-unread");
                        }
                    }
                })]
            }
        });

        menu.addSeparator();

        menu.add({
            scope: this,
            text: DeskKregator.FeedGridItemDel,
            iconCls: 'DeskKregator-icon-del-feed',
            handler: function(grid, rowIndex, ev){

                var boxTitle='', boxMessage='';

                // How many rows to delete ?
                if( rowSelected.length == 1 ) {
                 boxTitle = DeskKregator.BoxConfirmDelItemTitle;
                 boxMessage = DeskKregator.BoxConfirmDelItemMessage;
                } else {
                 boxTitle = DeskKregator.BoxConfirmDelItemsTitle;
                 boxMessage = DeskKregator.BoxConfirmDelItemsMessage;
                }


                // Show confirm box
                Ext.Msg.show({
                   scope: this,
                   title:boxTitle,
                   msg: boxMessage,
                   buttons: Ext.Msg.YESNOCANCEL,
                   fn: function(btn) {

                     if( btn == 'yes' ) {

                         this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutItemDel);

                         // Update DB
                         var delItem = new Ext.data.Connection();
                         delItem.request({
                             scope: this,
                             url: this.app.connection,
                             params: {
                                 moduleId: this.moduleId,
                                 fileName: 'php/desk-kregator.php',
                                 id_item: rowDel,
                                 what: 'del_items'
                             },
                             success: function(response, options){

                                 var o = Ext.util.JSON.decode(response.responseText);

                                 this.setStatusBar('DeskKregator-done', DeskKregator.StatutItemDelOk);

                                 // Delete ligne(s)
                                 for (var i = 0; i < rowSelected.length; i++) {

                                     var _nodeID = this.dsItems.getById(rowSelected[i].id).data.id_f;
                                     var unSeen = o.message.Node[_nodeID].unseen;
                                     var total = o.message.Node[_nodeID].total;
                                     this.dsItems.remove(this.dsItems.getById(rowSelected[i].id));
                                     this.updateFeedInfo(_nodeID, unSeen, total);

                                 }

                                 // Focus & Display next items
                                 if( this.dsItems.data.items.length > 0 ) {
                                  this.loadItem(0);
                                  this.PanelGridItem.getSelectionModel().selectRow(0);

                                 } else {

                                  // Clear Preview Panel
                                  this.PanelPreview.setTitle(DeskKregator.PreviewTitle);
                                  this.PanelPreview.body.dom.innerHTML = '';


                                 }

                             },
                             failure: function(form, action){
                                 this.setStatusBar('DeskKregator-error', DeskKregator.StatutItemDelNok);
                             }
                         });



                     }


                   },
                   animEl: 'elId',
                   icon: Ext.MessageBox.QUESTION
                });

            }
        });

        menu.showAt(ev.getXY());

    }, // onContextItemFeed

    markAsImportant: function(typeMark, rowId){

        var importantStatut = this.dsItems.getById(rowId).data.i;

        var typeMark = typeMark;
        var rowId = rowId;

        if ((importantStatut == 'y' && typeMark == 'n') || (importantStatut == 'n' && typeMark == 'y')) {

            var saveImportant = new Ext.data.Connection();
            saveImportant.request({
                scope: this,
                url: this.app.connection,
                params: {
                    moduleId: this.moduleId,
                    fileName: 'php/desk-kregator.php',
                    id_item: rowId,
                    typeMark: typeMark,
                    what: 'save_important'
                },
                success: function(){

                    if (typeMark == 'y') {
                        this.dsItems.getById(rowId).data.i = 'y';
                    }
                    else
                        if (typeMark == 'n') {
                            this.dsItems.getById(rowId).data.i = 'n';
                        }
                }
            });
        }
    }, //markAsImportant

    markAsSeenUnseen: function(typeMark, rowId, scope){

        this.scope = scope;

        var seenStatut = this.dsItems.getById(rowId).data.s;
        var typeMark = typeMark;
        var rowId = rowId;

        // Modify if necessary
        if ((seenStatut == 'y' && typeMark == 'n') || (seenStatut == 'n' && typeMark == 'y')) {

            var saveSeenUnseen = new Ext.data.Connection();
            saveSeenUnseen.request({
                scope: this,
                url: this.app.connection,
                params: {
                    moduleId: this.moduleId,
                    fileName: 'php/desk-kregator.php',
                    id_item: rowId,
                    typeMark: typeMark,
                    what: 'save_seenUnseen'
                },
                success: function(response, options){

                    var o = Ext.util.JSON.decode(response.responseText);

                    if (o.success) {

                        var node = this.PanelFeedTree.getNodeById(o.nodeID);
                        node.attributes.unseen = o.unSeen;
                        node.attributes.total = o.total;

                        // Update client data
                        if (typeMark == 'y') {
                            this.dsItems.getById(rowId).data.s = 'y';
                        } else if (typeMark == 'n') {
                                this.dsItems.getById(rowId).data.s = 'n';
                        }

                        this.updateFeedInfo(node.id, o.unSeen, o.total);
                    }
                }
            });

        }
    }, //markAsSeenUnseen

    markAllAsRead: function(node, scope) {

        var nb = scope.dsItems.data.length;

        for (var i = 0; i < nb; i++) {
            var r = Ext.get(scope.PanelGridItem.getView().getRow(i));
            r.replaceClass("DeskKregator-feed-unread", "DeskKregator-feed-read");
        }
        scope.markAsSeenDB(node.id, scope);
        node.ui.removeClass("DeskKregator-feed-Unseen");

    },

    markAsSeenDB: function(_nodeID, scope){

        this.scope = scope;

        var saveSeenUnseen = new Ext.data.Connection();
        saveSeenUnseen.request({
            scope: this,
            url: this.app.connection,
            params: {
                moduleId: this.moduleId,
                fileName: 'php/desk-kregator.php',
                id_feed: _nodeID,
                what: 'save_seenDB'
            },
            success: function(response, options){

                var o = Ext.util.JSON.decode(response.responseText);

                if (o.success) {

                    var node = this.PanelFeedTree.getNodeById(o.nodeID);
                    node.attributes.unseen = o.unSeen;
                    node.attributes.total = o.total;
                    this.updateFeedInfo(node.id, o.unSeen, o.total);

                }
            }
        });

    }, //markAsSeenDB

    openInWindow: function(rowId){
        var node = this.dsItems.getById(rowId);
        var link = node.data.u;
        window.open(link, 'win' + rowId);
    }, //openInWindow

    openInTab: function(feedID, title, link){

        var TabExist = this.PanelCenter.findById('DeskKregator-tab-' + feedID);

        if (TabExist) {
            this.PanelCenter.activate('DeskKregator-tab-' + feedID);
        }
        else {

            this.PanelCenter.add({
                id: 'DeskKregator-tab-' + feedID,
                linkTab: link,
                closable: true,
                title: title.ellipse(20),
                layout: 'fit',
                border: true,
                html: '<div class="DeskKregator-preview-content"><iframe width="100%" height="100%" frameborder="0" src="' + link + '" /></div>'

            });

            this.PanelCenter.activate('DeskKregator-tab-' + feedID);

        }

    }, //openInTab

    onClickFeed: function(node, ev){

        this.curNodeId = node.id;

        var nodeType = node.attributes.type;

        this.PanelCenter.activate('DeskKregator-main');

        this.gridClearFilter();

        // Delete data
        this.dsItems.removeAll();

        if (nodeType == 'folder') {

            this.PanelPreview.body.dom.innerHTML = '';

            this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutLoadFolder + " " + node.attributes.text);

            var ColIndex = this.PanelGridItem.getColumnModel().getIndexById('feed');
            this.PanelGridItem.getColumnModel().setHidden(ColIndex, false);

            // Set tab title
            Ext.getCmp('DeskKregator-main').setTitle(node.attributes.text.ellipse(20));
            this.linkDefaultTab = '';
            this.curFeedId = '*';

        }
        else {

            this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutLoadFeed + " " + node.attributes.text);

            var ColIndex = this.PanelGridItem.getColumnModel().getIndexById('feed');
            this.PanelGridItem.getColumnModel().setHidden(ColIndex, true);

            Ext.getCmp('DeskKregator-main').setTitle(node.attributes.text.ellipse(20));
            this.linkDefaultTab = node.attributes.url;
            this.curFeedId = node.id;

            var image;

            if ( node.attributes.image ) {
                image = "<img src=\"" + node.attributes.image + "\" alt=\"\" />";
            }
            else {
                image = '';
            }

            var content = '<div class="DeskKregator-feed-info">' +
            '<div class="DeskKregator-item-date"></div>' +
            '<div class="DeskKregator-item-title">' +
            node.attributes.desc +
            '</div>' +
            '<div class="DeskKregator-item-author"><a href="' +
            node.attributes.url +
            '" Ext:qtip="' +
            DeskKregator.previewLoadInNewPage +
            '" target="_blank">' +
            node.attributes.url +
            '</a></div>' +
            '</div>' +
            '<div class="DeskKregator-feed-content">' +
            '<div class="DeskKregator-feed-image">' +
            image +
            '</div>' +
            '</div>';

            this.PanelPreview.body.dom.innerHTML = content;

        }

        this.PanelPreview.setTitle(node.attributes.text);

        this.dsItems.baseParams = {
            'id_feed': this.curFeedId,
            'id_node': this.curNodeId
        };

        this.dsItems.load({
            params: {
                start: 0,
                limit: 25
            }
        });
    }, //onClickFeed

    showDelItemArbre: function(node){

        var titre, message, typeObj;

        if (node.attributes.type == 'file') {
            titre = DeskKregator.BoxConfirmDelFeedTitle;
            message = DeskKregator.BoxConfirmDelFeedMessage + node.attributes.text + ' ?';
        }

        if (node.attributes.type == 'folder') {
            titre = DeskKregator.BoxConfirmDelFolderTitle;
            message = String.format(DeskKregator.BoxConfirmDelFolderMessage, node.attributes.text);
        }

        Ext.Msg.show({
            scope: this,
            icon: Ext.MessageBox.QUESTION,
            title: titre,
            msg: message,
            buttons: Ext.MessageBox.YESNO,
            fn: function(btn){
                if (btn == 'yes') {
                    if (node.attributes.type == 'file') {
                        this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutDelFeed + node.attributes.text + '...');
                    }
                    else {
                        this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutDelFolder + node.attributes.text + '...');
                    }

                    // Update
                    var delNode = new Ext.data.Connection();
                    delNode.request({
                        scope: this,
                        url: this.app.connection,
                        params: {
                            moduleId: this.moduleId,
                            fileName: 'php/desk-kregator.php',
                            id_node: node.id,
                            what: 'del_nodes'
                        },
                        success: function(response, options){

                            var o = Ext.util.JSON.decode(response.responseText);

                            if (o.success) {

                                this.setStatusBar('DeskKregator-done', DeskKregator.StatutDone);

                                //Del node
                                var curNode = this.PanelFeedTree.selModel.selNode;
                                curNode.parentNode.removeChild(curNode);

                                // Return to initial state
                                Ext.getCmp('DeskKregator-main').setTitle(DeskKregator.FeedGridTabTitle);
                                this.linkDefaultTab = '';
                                this.dsItems.removeAll();

                                this.PanelPreview.setTitle(DeskKregator.PreviewTitle);
                                this.PanelPreview.body.dom.innerHTML = '';

                            }
                            else {
                                this.setStatusBar('DeskKregator-error', DeskKregator.StatutDelItemNok);
                            }

                        }
                    });

                }
            }
        });

    }, // showDelItemArbre

    showAddFeed: function(_nodeID){

        var FormAddFeed = new Ext.FormPanel({
            labelWidth: 40,
            frame: true,
            bodyStyle: 'padding:5px',
            width: 350,
            items: [{
                xtype:'textfield',
                fieldLabel: DeskKregator.BoxAddFeedUrl,
                name: 'newFeed',
                id: 'newFeed',
                width: 300
            },{
                xtype: 'checkbox',
                hideLabel: true,
                boxLabel: DeskKregator.BoxModFeedView,
                name: 'view',
                checked: false
            }]
        });

        var winAddFeed = new Ext.Window({
            animateEl: 'DeskKregator-add-feed-btn',
            title: DeskKregator.BoxAddFeedTitle,
            layout: 'fit',
            modal: true,
            iconCls: 'DeskKregator-icon-add-feed',
            width: 430,
            height: 160,
            closeAction: 'hide',
            bodyStyle: 'padding:5px',
            plain: true,
            items: FormAddFeed,

            buttons: [{
                text: DeskKregator.BoxAddFeedSaveBtn,
                scope: this,
                handler: function(){

                    this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutAddNewFeed);

                    var waitAddFeed = Ext.MessageBox.show({
                        msg: DeskKregator.StatutAddNewFeedWait,
                        progressText: DeskKregator.StatutAddNewFeedWaitInProgress,
                        width: 300,
                        wait: true,
                        waitConfig: {
                            interval: 200
                        }
                    });

                    FormAddFeed.form.submit({
                        scope: this,
                        url: this.app.connection,
                        params: {
                            moduleId: this.moduleId,
                            fileName: 'php/desk-kregator.php',
                            nodeID: _nodeID,
                            what: 'add_feed'
                        },
                        success: function(form, action){

                            // Add this new node to tree
                            var o = action.result, node;

                            if( o.nodeID === 0 ) { node = this.PanelFeedTree.getRootNode(); }
                            else { node = this.PanelFeedTree.getNodeById(o.nodeID); }

                            var nodeToAppend = new Ext.tree.TreeNode({
                                id:o.id,
                                text:o.text,
                                url: o.url,
                                url_feed: o.url_feed,
                                type: o.type,
                                desc: o.desc,
                                image: o.image,
                                view: o.view,
                                nodeID: o.nodeID,
                                unseen:o.unseen,
                                total:o.total,
                                uiProvider:Ext.tree.KregaColumnNodeUI,
                                leaf:true,
                                icon:o.icon,
                                iconCls:'',
                                refreshCycle:'on'
                            });

                            node.appendChild(nodeToAppend);

                            this.PanelFeedTree.expandAll();

                            var newNode = this.PanelFeedTree.getNodeById(o.id);
                            newNode.select();
                            this.onClickFeed(newNode);

                            this.updateFeedInfo(o.id, o.unseen, o.total);

                            FormAddFeed.form.reset();
                            waitAddFeed.hide();
                            winAddFeed.close();
                            this.setStatusBar('DeskKregator-done', DeskKregator.StatutAddNewFeedOk);
                        },

                        failure: function(form, action){
                            this.setStatusBar('DeskKregator-error', DeskKregator.StatutAddNewFeedNok + action.result.message);

                            waitAddFeed.hide();
                            Ext.get('newFeed').focus();

                        }
                    });

                }
            }, {
                text: DeskKregator.BoxAddFeedCancelBtn,
                handler: function(){
                    winAddFeed.close();
                }
            }]
        });

        winAddFeed.show(this);
        setTimeout("Ext.getDom('newFeed').focus()", 1000);

    }, //showAddFeed
    showConf: function(){

        var FormConf = new Ext.FormPanel({
            frame: true,
            bodyStyle: 'padding:5px',
            items: [{
                    layout: 'form',
                    bodyStyle: 'padding-right:5px',
                    items: [{
                      xtype: 'fieldset',
                      title: DeskKregator.WinConfFieldSetTitle0,
                      autoHeight: true,
                      autoWidth:true,
                      labelWidth: 55,
                      items: [
                        new Ext.ux.form.Spinner({
                           labelWidth: 55,
                           strategy: new Ext.ux.form.Spinner.NumberStrategy({minValue: '1', maxValue: '100'}),
                           fieldLabel: DeskKregator.WinConfFieldSetLabel0,
                           name: 'refresh_feed',
                           editable: false,
                           width: 50,
                           value: this.ConfRefreshFeed
                        })
                      ]
                    }]
            }, {
                xtype: 'fieldset',
                title: DeskKregator.WinConfFieldSetTitle1,
                autoHeight: true,
                checkboxToggle: true,
                checkboxName: 'old_items',
                collapsed: !this.ConfOldItems,
                labelWidth: 100,
                items: [
                  new Ext.ux.form.Spinner({
                      strategy: new Ext.ux.form.Spinner.NumberStrategy({minValue: '1', maxValue: '100'}),
                      fieldLabel: DeskKregator.WinConfFieldSetLabel1,
                      name: 'old_items_day',
                      editable: false,
                      width: 50,
                      value: this.ConfOldItemsDay
                  })
                ]
            }]
        });

        var winConf = new Ext.Window({
            scope: this,
            title: DeskKregator.WinConfTitle,
            layout: 'fit',
            modal: true,
            iconCls: 'DeskKregator-icon-conf',
            width: 450,
            height: 260,
            bodyStyle: 'padding:5px',
            plain: true,
            items: FormConf,

            buttons: [{
                text: DeskKregator.WinConfSaveBtn,
                scope: this,
                handler: function(){

                    this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutConfWait);

                    FormConf.form.submit({
                        scope: this,
                        url: this.app.connection,
                        params: {
                            moduleId: this.moduleId,
                            fileName: 'php/desk-kregator.php',
                            what: 'mod_user_conf'
                        },
                        success: function(form, action){

                            var o = action.result;

                            this.ConfRefreshFeed = o.refresh_feed;
                            this.ConfOldItems = o.old_items;
                            this.ConfOldItemsDay = o.old_items_day;

                            this.setStatusBar('DeskKregator-done', DeskKregator.StatutConfOk);

                            winConf.hide();
                        },
                        failure: function(form, action){
                            this.setStatusBar('DeskKregator-error', DeskKregator.StatutConfNok);
                        }
                    });

                }
            }, {
                text: DeskKregator.WinConfCancelBtn,
                handler: function(){
                    winConf.hide();
                }
            }]
        });
        winConf.show(this);
    }, //showConf

    showModFeed: function(node){

        var viewValue = false;
        if (node.attributes.view == 'site') {
            viewValue = true;
        }

        var refreshCycleValue = false;
        if (node.attributes.refreshCycle == 'off') {
            refreshCycleValue = true;
        }

        var FormModFeed = new Ext.FormPanel({
            labelWidth: 40,
            frame: true,
            bodyStyle: 'padding:5px',
            items: [{
                xtype: 'fieldset',
                title: node.text,
                autoHeight: true,
                defaultType: 'textfield',
                items: [{
                    fieldLabel: DeskKregator.BoxModFeedName,
                    name: 'modFeed',
                    value: node.text,
                    width: 300
                }, {
                    fieldLabel: 'Url ',
                    name: 'url',
                    readOnly: true,
                    value: node.attributes.url_feed,
                    width: 300
                }]
            }, {
                xtype: 'fieldset',
                title: DeskKregator.BoxModFeedOption,
                autoHeight: true,
                defaultType: 'checkbox',
                items: [{
                    hideLabel: true,
                    boxLabel: DeskKregator.BoxModFeedView,
                    name: 'view',
                    checked: viewValue
                },{
                    hideLabel: true,
                    boxLabel: 'Exclude from refresh cycle',
                    name: 'refreshCycle',
                    checked: refreshCycleValue
                }]
            }]
        });

        this.winModFeed = new Ext.Window({
            scope: this,
            title: DeskKregator.BoxModFeedTitle,
            layout: 'fit',
            modal: true,
            iconCls: 'DeskKregator-icon-mod-feed',
            width: 450,
            height: 280,
            closeAction: 'hide',
            bodyStyle: 'padding:5px',
            plain: true,
            items: FormModFeed,

            buttons: [{
                text: DeskKregator.BoxModFeedSaveBtn,
                scope: this,
                handler: function(){

                    this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutModFeed);

                    FormModFeed.form.submit({
                        params: {
                            moduleId: this.moduleId,
                            fileName: 'php/desk-kregator.php',
                            id_feed: node.attributes.id,
                            what: 'mod_feed'
                        },
                        scope: this,
                        url: this.app.connection,
                        success: function(form, action){

                            var o = action.result;

                            // Update tree
                            node.setText(o.nom);
                            node.attributes.view = o.view;
                            node.attributes.refreshCycle = o.refreshCycle;
                            this.setStatusBar('DeskKregator-done', DeskKregator.StatutModFeedOk);
                            this.winModFeed.hide();
                        },
                        failure: function(form, action){
                            this.setStatusBar('DeskKregator-error', DeskKregator.StatutModFeedNok);
                        }
                    });

                }
            }, {
                scope:this,
                text: DeskKregator.BoxModFeedCancelBtn,
                handler: function(){
                    this.winModFeed.hide();
                }
            }]
        });
        this.winModFeed.show(this);
    }, //showModFeed

    showAddFolder: function(_nodeID){

        var FormAddFolder = new Ext.FormPanel({
            labelWidth: 45,
            id: 'form-add-folder',
            frame: true,
            bodyStyle: 'padding:5px 5px 0',
            width: 350,
            defaults: {
                width: 280
            },
            defaultType: 'textfield',
            items: [{
                fieldLabel: DeskKregator.BoxAddFolderName,
                name: 'newFolder',
                id: 'newFolder'
            }]

        });

        var winAddFolder = new Ext.Window({
            scope: this,
            animateEl: 'DeskKregator-add-feed-btn',
            title: DeskKregator.BoxAddFolderTitle,
            layout: 'fit',
            modal: true,
            iconCls: 'DeskKregator-icon-add-folder',
            width: 400,
            height: 130,
            closeAction: 'hide',
            plain: true,
            items: FormAddFolder,
            buttons: [{
                id:'DeskKregator-btnOK-id-add-folder',
                text: DeskKregator.BoxAddFolderSaveBtn,
                scope: this,
                handler: function(){

                    // Disable btn
                    Ext.getCmp('DeskKregator-btnOK-id-add-folder').disable();
                    Ext.getCmp('DeskKregator-btnCANCEL-id-add-folder').disable();

                    this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutAddNewFolder);

                    FormAddFolder.form.submit({
                        scope: this,
                        url: this.app.connection,
                        params: {
                            moduleId: this.moduleId,
                            fileName: 'php/desk-kregator.php',
                            nodeID: _nodeID,
                            what: 'add_folder'
                        },
                        success: function(form, action){

                            var o = action.result, node;

                            this.setStatusBar('DeskKregator-done', DeskKregator.StatutAddNewFolderOk);

                            // Add this new node to tree

                            if( o.nodeID == 0 ) { node = this.PanelFeedTree.getRootNode(); }
                            else { node = this.PanelFeedTree.getNodeById(o.nodeID); }

                            node.appendChild(new Ext.tree.TreeNode({
                                text: o.name,
                                id: o.id,
                                leaf: false,
                                iconCls: 'DeskKregator-feed-folder',
                                type: 'folder',
                                children:[],
                                nodeID: o.nodeID
                            }));

                            var newNode = this.PanelFeedTree.getNodeById(o.id);
                            newNode.select();

                            FormAddFolder.form.reset();
                            Ext.getCmp('DeskKregator-btnOK-id-add-folder').enable();
                            Ext.getCmp('DeskKregator-btnCANCEL-id-add-folder').enable();
                            winAddFolder.close();
                        },
                        failure: function(form, action){
                            this.setStatusBar('DeskKregator-done', DeskKregator.StatutAddNewFolderNok);
                        }
                    });

                }
            }, {
                scope:this,
                text: DeskKregator.BoxAddFolderCancelBtn,
                id:'DeskKregator-btnCANCEL-id-add-folder',
                handler: function(){
                    winAddFolder.close();
                }
            }]
        });

        winAddFolder.show(this);
        setTimeout("Ext.getDom('newFolder').focus()", 1000);

    }, //showAddFolder

    showImport: function(_nodeID){

        var FormImport = new Ext.FormPanel({
            labelWidth: 45,
            labelAlign: 'top',
            id: 'form-import',
            fileUpload: true,
            url: this.app.connection+'?moduleId='+this.moduleId+'&fileName=php/desk-kregator.php&what=import',
            frame: true,
            bodyStyle: 'padding: 10px 10px 0 10px;',
            autoHeight: true,
            labelWidth: 50,
            defaults: {
                anchor: '95%',
                allowBlank: false,
                msgTarget: 'side'
            },

            items: [{
                fieldLabel: DeskKregator.WinImportLibel1,
                xtype: 'textfield',
                name: 'importFolder',
                value: DeskKregator.WinImportDefaultValue
            }, {
                xtype: 'fileuploadfield',
                fieldLabel: DeskKregator.WinImportLibel2,
                name: 'importFile',
                id: 'importFile',
                emptyText: DeskKregator.WinImportInfo,
                buttonCfg: {
                    text: '',
                    iconCls: 'upload-icon'
                }

            }]

        });

        var winImport = new Ext.Window({
            animateEl: 'DeskKregator-add-feed-btn',
            title: DeskKregator.WinImportTitle,
            layout: 'fit',
            modal: true,
            iconCls: 'DeskKregator-icon-import',
            width: 400,
            height: 210,
            plain: true,
            bodyStyle: 'padding:5px',
            items: FormImport,

            buttons: [{
                text: DeskKregator.WinImportSaveBtn,
                scope: this,
                handler: function(){

                    this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutImportWait);

                    FormImport.form.submit({
                        scope: this,
                        success: function(form, action){

                            var o = action.result;

                            if (o.success) {

                                // Add folder
                                this.PanelFeedTree.getRootNode().appendChild(new Ext.tree.TreeNode({
                                    text: o.folderText,
                                    id: o.folderId,
                                    leaf: false,
                                    iconCls: 'DeskKregator-feed-folder',
                                    type: 'folder',
                                    children:[],
                                    nodeID: 0
                                }));

                                this.PanelFeedTree.getNodeById(o.folderId).expand();

                                var new_feed = [];
                                var reg = new RegExp("[|]+", "g");

                                var tmp_feed = o.new_feed;
                                new_feed = tmp_feed.split(reg);

                                // On ajoute les flux
                                for (var i = 0; i < new_feed.length; i++) {

                                    if ( !new_feed[i]) { continue; }

                                    this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutAddNewFeed);

                                    var saveFeed = new Ext.data.Connection();
                                    saveFeed.request({
                                        scope: this,
                                        url: this.app.connection,
                                        params: {
                                            moduleId: this.moduleId,
                                            fileName: 'php/desk-kregator.php',
                                            newFeed: new_feed[i],
                                            nodeID: o.folderId,
                                            what: 'add_feed'
                                        },

                                        success: function(response, options){

                                            var o2 = Ext.util.JSON.decode(response.responseText);

                                            if (o2.success) {

                                                // Add the new node
                                                this.PanelFeedTree.getNodeById(o.folderId).appendChild(new Ext.tree.TreeNode({
                                                    id:o2.id,
                                                    text:o2.text,
                                                    url: o2.url,
                                                    url_feed: o2.url_feed,
                                                    type: o2.type,
                                                    desc: o2.desc,
                                                    image: o2.image,
                                                    view: o2.view,
                                                    nodeID: o2.nodeID,
                                                    unseen:o2.unseen,
                                                    total:o2.total,
                                                    uiProvider:Ext.tree.KregaColumnNodeUI,
                                                    leaf:true,
                                                    icon:o2.icon,
                                                    iconCls:'',
                                                    refreshCycle:'on'
                                                }));

                                                this.updateFeedInfo(o2.id, o2.unseen, o2.total);

                                                this.setStatusBar('DeskKregator-done', DeskKregator.StatutAddNewFeedOk);

                                            } else {
                                                this.setStatusBar('DeskKregator-error', DeskKregator.StatutAddNewFeedNok + o2.message);
                                            }
                                        }
                                    });

                                }

                                this.setStatusBar('DeskKregator-done', DeskKregator.StatutImportOk);

                            } else {

                                Ext.MessageBox.show({
                                    title: 'erreur',
                                    msg: 'erreur' + o.msg,
                                    buttons: Ext.MessageBox.OK,
                                    animEl: 'mb9',
                                    icon: Ext.MessageBox.ERROR
                                });

                            }

                            FormImport.form.reset();
                            winImport.close();
                        },
                        failure: function(form, action){
                            this.setStatusBar('DeskKregator-done', DeskKregator.StatutImportNok + action.result.msg);
                        }
                    });

                }
            }, {
                text: DeskKregator.WinImportCancelBtn,
                handler: function(){
                    winImport.close();
                }
            }]
        });

        winImport.show(this);

    }, //showImport

    showAbout: function(){

        if (!this.winAbout) {

            this.winAbout = new Ext.Window({
                layout: 'fit',
                width: 420,
                height: 300,
                iconCls: 'DeskKregator-icon-about',
                modal: true,
                title: DeskKregator.WinAboutTitle,
                closeAction: 'hide',
                plain: true,
                bodyStyle: 'color:#000',
                items: new Ext.TabPanel({
                    autoTabs: true,
                    activeTab: 0,
                    border: false,
                    defaults: {
                        autoScroll: true
                    },
                    items: [{
                        title: DeskKregator.WinAboutTab0,
                        html: '<div id="DeskKregator-about"><img src="system/modules/Desk-Kregator/img/default/logo.png" alt="" /></div><div id="DeskKregator-about-info">(c) 2007 - 2008, Yannick Torr&egrave;s - <a href="mailto:yannick.torres@keliglia.com">yannick.torres@keliglia.com</a></div>'
                    }, {
                        title: DeskKregator.WinAboutTab1,
                        bodyStyle: 'padding:5px',
                        html: '<div id="DeskKregator-credit"><ul><li><a href="http://extjs.com/forum/member.php?u=12208">Franck Carrouget</a><br><span class="DeskKregator-credit-info">' + DeskKregator.WinAboutTab1Credits0 + '</span></li><li><a href="http://extjs.com/forum/member.php?u=6915">Andriy Levytskyy</a><br><span class="DeskKregator-credit-info">' + DeskKregator.WinAboutTab1Credits1 + '</span></li><li><a href="http://extjs.com/forum/member.php?u=1485">K0bo</a><br><span class="DeskKregator-credit-info">' + DeskKregator.WinAboutTab1Credits21 + '</span></li><li><a href="http://www.alsacreations.fr">AlsaCr&eacute;ations</a><br><span class="DeskKregator-credit-info"><a href="http://www.alsacreations.fr/dewplayer">DewPlayer</a> & <a href="http://www.alsacreations.fr/dewtube">DewTube</a></span></li><li><a href="http://extjs.com">ExtJs Team</a><br><span class="DeskKregator-credit-info">' + DeskKregator.WinAboutTab1Credits3 + '</span></li></ul></div>'
                    }, {
                        title: DeskKregator.WinAboutTab2,
                        autoLoad: {
                            url: 'system/modules/Desk-Kregator/license_LGPL_v2.txt'
                        }
                    }]
                }),

                buttons: [{
                    scope:this,
                    text: DeskKregator.WinAboutClose,
                    handler: function(){
                        this.winAbout.hide();
                    }
                }]
            });
        }
        this.winAbout.show(this);

    }, //showAbout

    gridClearFilter: function(){

        // Initialize search

        Ext.getCmp('DeskKregator-search').setValue('');
        Ext.getCmp('DeskKregator-etat').setValue('all', true);
        Ext.getCmp('DeskKregator-search').triggers[0].hide();

    }, // gridClearFilter

    setStatusBar: function(style, message){

        var statusBar = Ext.getCmp('DeskKregator-statusBar');

        statusBar.setStatus({
            text: message,
            iconCls: style
        });
    }, // setStatusBar

    searchFeed: function() {

        var count = 0;

        this.FeedNeedUpdate = [];
        this.ConfGoRefresh = true;

        // We change "refresh" to "stop" icon
        Ext.getCmp('DeskKregator-add-refresh-feed-btn').setHandler(function() {this.ConfGoRefresh = false;}, this);
        Ext.getCmp('DeskKregator-add-refresh-feed-btn').setIconClass('DeskKregator-refresh-stop-btn');

        function _searchFeed(node, scope){

            var kids = node.childNodes;
            var len = kids.length;
            for (var i = 0; i < len; i++) {

                if (kids[i].attributes.type == 'file') {

                    // Exclude feed where refreshCycle == off
                    if( kids[i].attributes.refreshCycle == 'on' ) {

                      scope.FeedNeedUpdate[count] = [];

                      scope.FeedNeedUpdate[count].nodeID = kids[i].id;
                      scope.FeedNeedUpdate[count].id = kids[i].attributes.id;
                      scope.FeedNeedUpdate[count].texte = kids[i].text;
                      ++count;

                    }

                }
                _searchFeed(kids[i], scope);
            }
        }

        _searchFeed(this.PanelFeedTree.getRootNode(), this);

        this.goUpdateAllFeed(0);

        this.TaskSearchFeed.delay(this.ConfRefreshFeed * 60 * 1000);

    }, //searchFeed

    goUpdateAllFeed: function(FeedIndex){

        if (this.FeedNeedUpdate[FeedIndex] && this.ConfGoRefresh ) {
            this.updateFeed(this.FeedNeedUpdate[FeedIndex].texte, this.FeedNeedUpdate[FeedIndex].id, this.FeedNeedUpdate[FeedIndex].nodeID, 'on', FeedIndex + 1);
        } else {

          // Return to default button refresh
          Ext.getCmp('DeskKregator-add-refresh-feed-btn').setHandler(function() {this.TaskSearchFeed.delay(1000);}, this);
          Ext.getCmp('DeskKregator-add-refresh-feed-btn').setIconClass('DeskKregator-refresh-btn');
        }


    }, // goUpdateAllFeed

    updateFeed: function(id_texte, id_Feed, _nodeID, cache, NextFeedIndex){

        this.setStatusBar('DeskKregator-inProgress', DeskKregator.StatutUpdateFeed + id_texte + '...');

        this.PanelFeedTree.getNodeById(_nodeID).ui.removeClass("DeskKregator-feed-Unseen");
        this.PanelFeedTree.getNodeById(_nodeID).ui.addClass("x-tree-node-disabled");

        var UpdateFeed = new Ext.data.Connection();

        UpdateFeed.request({
            scope: this,
                url: this.app.connection,
            params: {
                moduleId: this.moduleId,
                fileName: 'php/desk-kregator.php',
                idFeed: id_Feed,
                cache: cache,
                what: 'update_feed'
            },
            success: function(response, options){

                var o = Ext.util.JSON.decode(response.responseText);

                if (o.success) {

                    this.setStatusBar('DeskKregator-done', id_texte + ' : ' + DeskKregator.StatutDone);
                    this.PanelFeedTree.getNodeById(_nodeID).ui.removeClass("x-tree-node-disabled");
                    this.updateFeedInfo(_nodeID, o.unseen, o.new_nb_item);

                    // if there is new items & items for this feed are displayed, we update the grid
                    if (o.new_nb_item > o.old_nb_item && this.curFeedId == id_Feed) {
                        this.dsItems.reload();
                    }

                }
                else {

                    this.setStatusBar('DeskKregator-error', DeskKregator.StatutUpdateFeedNok + id_texte);

                    this.PanelFeedTree.getNodeById(_nodeID).ui.removeClass("x-tree-node-disabled");
                    this.PanelFeedTree.getNodeById(_nodeID).ui.addClass("x-tree-node-error");
                }

                if (NextFeedIndex >= 0) {
                    this.goUpdateAllFeed(NextFeedIndex);
                }

            }
        });
    }, //updateFeed

    renderDate: function(TmpDate){

        if (TmpDate == '0000-00-00 00:00:00') { return '-'; }

        var dt = new Date();
        dt = Date.parseDate(TmpDate, "Y-m-d h:i:s");
        return dt.format(DeskKregator.DateDisplay);

    } //renderDate

});
